@@ -7,7 +7,7 @@ from mkdocs.plugins import BasePlugin
 from mkdocs.config import config_options
 from mkdocs.structure.files import File
 from mkdocs.structure.pages import Page
-from mkdocs.utils import write_file, copy_file, get_relative_url, warning_filter
+from mkdocs.utils import write_file, copy_file, get_relative_url
 from mkdocs.exceptions import PluginError
 
 from mkdocs_print_site_plugin.renderer import Renderer
@@ -15,7 +15,6 @@ from mkdocs_print_site_plugin.utils import flatten_nav, get_theme_name
 from mkdocs_print_site_plugin.urls import is_external
 
 logger = logging.getLogger("mkdocs.plugins")
-logger.addFilter(warning_filter)
 
 HERE = os.path.dirname(os.path.abspath(__file__))
 
@@ -358,6 +357,18 @@ class PrintSitePlugin(BasePlugin):
                 .add_javascript_variables(html, self.print_page, config)
             )
 
+        # Compatibility with mkdocs-drawio
+        # As this plugin adds renderer html for every drawio diagram
+        # referenced in your markdown files. This rendering happens
+        # in the on_post_page event, which is skipped by this plugin
+        # therefore we need to manual execute the drawio plugin renderer here. 
+        if config.get("plugins", {}).get("drawio"):
+            html = (
+                config.get("plugins", {})
+                    .get("drawio")
+                    .render_drawio_diagrams(html, self.print_page)
+            )
+
         # Compatibility with https://github.com/g-provost/lightgallery-markdown
         # This plugin insert link hrefs with double dashes, f.e.
         # <link href="//assets/css/somecss.css">
